@@ -80,11 +80,11 @@ telemetry_opts = [
                 default=False,
                 help="Disable SSL certificate validation when running "
                      "scenario tests"),
-    cfg.StrOpt('sg_core_service_url',
+    cfg.URIOpt('sg_core_service_url',
                default="http://127.0.0.1:3000",
                help="URL to sg-core prometheus endpoint"),
-    cfg.StrOpt('prometheus_service_url',
-               default="127.0.0.1:9090",
+    cfg.URIOpt('prometheus_service_url',
+               default="http://127.0.0.1:9090",
                help="URL to prometheus endpoint"),
     cfg.IntOpt('ceilometer_polling_interval',
                default=300,
